PppEvent

Enum PppEvent 

pub enum PppEvent {
Show 28 variants NoError, ParameterError, OpenError, DeviceError, AllocError, UserError, DisconnectError, AuthFailError, ProtocolError, PeerDeadError, IdleTimeoutError, MaxConnectTimeoutError, LoopbackError, PhaseDead, PhaseMaster, PhaseHoldoff, PhaseInitialize, PhaseSerialConnection, PhaseDormant, PhaseEstablish, PhaseAuthenticate, PhaseCallback, PhaseNetwork, PhaseRunning, PhaseTerminate, PhaseDisconnect, PhaseFailed, Other(i32),
}
Represents a PPP event on the system event loop

Variants



NoError

No error



ParameterError

Invalid parameter



OpenError

Unable to open PPP session



DeviceError

Invalid I/O device for PPP



AllocError

Unable to allocate resources



UserError

User interrupt



DisconnectError

Connection lost



AuthFailError

Failed authentication challenge



ProtocolError

Failed to meet protocol



PeerDeadError

Connection timeout



IdleTimeoutError

Idle Timeout



MaxConnectTimeoutError

Max connect time reached



LoopbackError

Loopback detected



PhaseDead



PhaseMaster



PhaseHoldoff



PhaseInitialize



PhaseSerialConnection



PhaseDormant



PhaseEstablish



PhaseAuthenticate



PhaseCallback



PhaseNetwork



PhaseRunning



PhaseTerminate



PhaseDisconnect



PhaseFailed



Other(i32)

An event ID not recognised by this version of the library was received.

This variant is produced instead of panicking when an unknown event ID arrives, allowing applications to remain forward-compatible with ESP-IDF versions that introduce new PPP events.